package com.tofly.xrtymis.custom.schedule;

import com.tofly.xrtymis.custom.service.GdglinfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

/**
 * @author fcl
 * @date 2021/6/16 15:54
 */
@Component
public class ScheduledTask {
    @Autowired
    private GdglinfoService gdglinfoService;


//    // 0/5 * * * * ?表示每隔5秒执行一次这个方法
//    @Scheduled(cron = "0/5 * * * * ?")
//    public void task1() {
//        System.out.println("**************task1执行了..");
//    }

    //0 */5 * * * ?表示每五分钟执行一次该方法
    // TODO 接单时限不需要
    //@Scheduled(cron = "0 0/5 * * * ?")
    public void  task2(){
        gdglinfoService.timeoutAnalysis();
    }
    //0 0/59 * * * ?表示每59分钟执行一次该方法
    @Scheduled(cron = "0 0/59 * * * ?")
    public void  task3(){
        gdglinfoService.rzczTimeout();
        gdglinfoService.rzshTimeout();
        gdglinfoService.rzzjTimeout();
        gdglinfoService.jgczTimeout();
//        gdglinfoService.gdcsTimeout();
    }


    /**
     * 定时处理修改超时判断是否超时，修改超时标记
     */
    @Scheduled(cron = "0 0/5 * * * ?")
    public void timeOutTask(){
        System.out.println("==========================================================");
        gdglinfoService.jdTimeout();
        gdglinfoService.rzcsTimeout();
        gdglinfoService.shcsTimeout();
        gdglinfoService.zjcsTimeout();
        gdglinfoService.czcsTimeout();
        gdglinfoService.allcsTimeout();
    }
    /**
     * 定时处理修改超时判断是否超时，修改超时标记
     */
    @Scheduled(cron = "0 0/5 * * * ?")
    public void timeForeignCallback(){
        gdglinfoService.foreignOrderCallback();
    }

}
